"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.copyCollectionAction = exports.copyCollection = void 0;
const serviceAccountTools_1 = require("../utils/serviceAccountTools");
const firebaseTools_1 = require("../utils/firebaseTools");
const chalk = require("chalk");
const promptTools_1 = require("../utils/promptTools");
const utils_1 = require("../utils/utils");
exports.copyCollection = {
    name: 'copy-collection',
    description: 'Copy collection(s) from a source project to a destination project',
    arguments: [
        {
            name: 'destinationServiceAccountPath',
            info: 'Path to the service account used to access the destination project',
        },
    ],
    options: [
        {
            name: 'source-service-account-path',
            argName: 'sourceServiceAccountPath',
            short: 's',
            info: 'Path to the service account used to access the source project',
        },
        {
            name: 'collections',
            argName: 'collections',
            short: 'c',
            info: 'Name of the collection(s) to copy',
            list: true,
        },
        {
            name: 'all-collections',
            short: 'a',
            info: "Use this option instead of 'collections' to select all collections in source project",
        },
        {
            name: 'force',
            short: 'f',
            info: 'Forces the operation to be executed without user validation',
        },
    ],
    action: copyCollectionAction,
};
async function copyCollectionAction(destinationServiceAccountPath, options) {
    const sourceServicePrompt = 'What is the path to the firebase service account of the source project ?';
    const sourceServiceAccount = (options === null || options === void 0 ? void 0 : options.sourceServiceAccountPath)
        ? await (0, serviceAccountTools_1.validateAndParseServiceAccountPath)(options.sourceServiceAccountPath, (options === null || options === void 0 ? void 0 : options.force) != true)
        : await (0, serviceAccountTools_1.getServiceAccountWithConfigOrUserInput)(sourceServicePrompt);
    (0, promptTools_1.promptProjectInfos)(sourceServiceAccount);
    const sourceApp = await (0, serviceAccountTools_1.getFirebaseApp)(sourceServiceAccount, 'source');
    const sourceDb = sourceApp.firestore();
    const destinationServicePrompt = 'What is the path to the firebase service account of the destination project ?';
    const destinationServiceAccount = await (0, serviceAccountTools_1.validateAndParseServiceAccountPath)(destinationServiceAccountPath, (options === null || options === void 0 ? void 0 : options.force) != true, destinationServicePrompt);
    const destinationApp = await (0, serviceAccountTools_1.getFirebaseApp)(destinationServiceAccount, 'destination');
    const destinationDb = destinationApp.firestore();
    let collectionsName = await (0, firebaseTools_1.validateCollectionList)(sourceDb, options === null || options === void 0 ? void 0 : options.allCollections, options === null || options === void 0 ? void 0 : options.collections, sourceServiceAccount.project_id, (options === null || options === void 0 ? void 0 : options.force) != true);
    if ((options === null || options === void 0 ? void 0 : options.force) != true) {
        await (0, promptTools_1.promptValidateOrExit)(`Are you sure you want to copy the content of the collections${chalk.whiteBright((0, utils_1.listToBullets)(collectionsName))}\n from the project '${chalk.whiteBright(sourceServiceAccount.project_id)}' to the project '${chalk.whiteBright(destinationServiceAccount.project_id)}' ?`);
    }
    await (0, firebaseTools_1.copyCollectionAcrossProjects)(collectionsName, sourceDb, destinationDb);
    (0, promptTools_1.logSuccess)(`Collection copied from ${sourceServiceAccount.project_id} to ${destinationServiceAccount.project_id}.`);
}
exports.copyCollectionAction = copyCollectionAction;
//# sourceMappingURL=copyCollection.js.map