"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteCollections = void 0;
const serviceAccountTools_1 = require("../utils/serviceAccountTools");
const firebaseTools_1 = require("../utils/firebaseTools");
const chalk = require("chalk");
const promptTools_1 = require("../utils/promptTools");
const utils_1 = require("../utils/utils");
exports.deleteCollections = {
    name: 'delete-collection',
    description: 'Delete collection(s) inside a defined project',
    arguments: [],
    options: [
        {
            name: 'service-account-path',
            argName: 'serviceAccountPath',
            short: 's',
            info: 'Path to the service account used to access the project',
        },
        {
            name: 'collections',
            argName: 'collections',
            short: 'c',
            info: 'Name of the collection(s) to delete',
            list: true,
        },
        {
            name: 'all-collections',
            short: 'a',
            info: "Use this option instead of 'collections' to delete all collections in the project",
        },
        {
            name: 'force',
            short: 'f',
            info: 'Forces the operation to be executed without user validation',
        },
    ],
    action: deleteCollectionsAction,
};
async function deleteCollectionsAction(options) {
    const serviceAccount = (options === null || options === void 0 ? void 0 : options.serviceAccountPath)
        ? await (0, serviceAccountTools_1.validateAndParseServiceAccountPath)(options.serviceAccountPath, (options === null || options === void 0 ? void 0 : options.force) != true)
        : await (0, serviceAccountTools_1.getServiceAccountWithConfigOrUserInput)();
    (0, promptTools_1.promptProjectInfos)(serviceAccount);
    const app = await (0, serviceAccountTools_1.getFirebaseApp)(serviceAccount);
    const db = app.firestore();
    let collectionsName = await (0, firebaseTools_1.validateCollectionList)(db, options === null || options === void 0 ? void 0 : options.allCollections, options === null || options === void 0 ? void 0 : options.collections, serviceAccount.project_id, (options === null || options === void 0 ? void 0 : options.force) != true);
    if ((options === null || options === void 0 ? void 0 : options.force) != true) {
        await (0, promptTools_1.promptCustomValidateOrExit)(`Are you sure you want to delete the collections${chalk.whiteBright((0, utils_1.listToBullets)(collectionsName))}\nfrom the project '${chalk.whiteBright(serviceAccount.project_id)}' ?\n\nTo validate type '${chalk.whiteBright(serviceAccount.project_id)}', else to cancel type '${chalk.whiteBright('cancel')}'.`, serviceAccount.project_id, 'cancel', `Please enter \'${chalk.whiteBright(serviceAccount.project_id)}\' to continue or '${chalk.whiteBright('cancel')}' to cancel.`);
    }
    await (0, firebaseTools_1.deleteCollectionsFromFirestore)(collectionsName, db);
    (0, promptTools_1.logSuccess)(`Successfully deleted collections from ${serviceAccount.project_id}.`);
}
//# sourceMappingURL=deleteCollection.js.map