"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.exportCollection = void 0;
const serviceAccountTools_1 = require("../utils/serviceAccountTools");
const chalk = require("chalk");
const firebaseTools_1 = require("../utils/firebaseTools");
const promptTools_1 = require("../utils/promptTools");
const utils_1 = require("../utils/utils");
exports.exportCollection = {
    name: 'export-collection',
    description: 'Export a collection as JSON',
    arguments: [
        {
            name: 'collections',
            info: 'collection(s) you wish to export',
            list: true,
            optional: true,
        },
    ],
    options: [
        {
            name: 'output-file',
            argName: 'outputFile',
            short: 'o',
            info: 'Path to the JSON file that will be generated',
        },
        {
            name: 'service-account-path',
            argName: 'serviceAccountPath',
            short: 's',
            info: 'Path to the service account used to access the project',
        },
        {
            name: 'overwrite',
            short: 'w',
            info: 'Force overwrite output file if already exists',
        },
        {
            name: 'all-collections',
            short: 'a',
            info: "Use this option instead of 'collections' export all collections in the project",
        },
        {
            name: 'force',
            short: 'f',
            info: 'Forces the operation to be executed without user validation',
        },
    ],
    action: exportCollectionAction,
};
async function exportCollectionAction(collections, options) {
    const serviceAccount = (options === null || options === void 0 ? void 0 : options.serviceAccountPath)
        ? await (0, serviceAccountTools_1.validateAndParseServiceAccountPath)(options.serviceAccountPath, (options === null || options === void 0 ? void 0 : options.force) != true)
        : await (0, serviceAccountTools_1.getServiceAccountWithConfigOrUserInput)();
    (0, promptTools_1.promptProjectInfos)(serviceAccount);
    const app = await (0, serviceAccountTools_1.getFirebaseApp)(serviceAccount);
    const db = app.firestore();
    let collectionsName = await (0, firebaseTools_1.validateCollectionList)(db, options === null || options === void 0 ? void 0 : options.allCollections, collections, serviceAccount.project_id, (options === null || options === void 0 ? void 0 : options.force) != true);
    const filename = await (0, promptTools_1.getFilenameWithOverwriteValidation)(options === null || options === void 0 ? void 0 : options.outputFile, options === null || options === void 0 ? void 0 : options.overwrite, 'firestore_export', (options === null || options === void 0 ? void 0 : options.force) != true);
    if ((options === null || options === void 0 ? void 0 : options.force) != true) {
        await (0, promptTools_1.promptValidateOrExit)(`Are you sure you want to export the content of the collections${chalk.whiteBright((0, utils_1.listToBullets)(collectionsName))}\n from the project '${chalk.whiteBright(serviceAccount.project_id)}' to the file '${chalk.whiteBright(filename)}' ?`);
    }
    await (0, firebaseTools_1.exportJsonFromFirestore)(collectionsName, filename, db);
    (0, promptTools_1.logSuccess)(`Successfully exported data from ${serviceAccount.project_id} into ${filename}.`);
}
//# sourceMappingURL=exportCollection.js.map