"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.exportRemoteConfig = void 0;
const serviceAccountTools_1 = require("../utils/serviceAccountTools");
const chalk = require("chalk");
const firebaseTools_1 = require("../utils/firebaseTools");
const promptTools_1 = require("../utils/promptTools");
exports.exportRemoteConfig = {
    name: 'export-remote-config',
    description: 'Export remote config as JSON',
    arguments: [],
    options: [
        {
            name: 'output-file',
            argName: 'outputFile',
            short: 'o',
            info: 'Path to the JSON file that will be generated',
        },
        {
            name: 'service-account-path',
            argName: 'serviceAccountPath',
            short: 's',
            info: 'Path to the service account used to access the project',
        },
        {
            name: 'overwrite',
            short: 'w',
            info: 'Force overwrite the output file if it already exists',
        },
        {
            name: 'force',
            short: 'f',
            info: 'Forces the operation to be executed without user validation',
        },
    ],
    action: exportRemoteConfigAction,
};
async function exportRemoteConfigAction(options) {
    const serviceAccount = (options === null || options === void 0 ? void 0 : options.serviceAccountPath)
        ? await (0, serviceAccountTools_1.validateAndParseServiceAccountPath)(options.serviceAccountPath, (options === null || options === void 0 ? void 0 : options.force) != true)
        : await (0, serviceAccountTools_1.getServiceAccountWithConfigOrUserInput)();
    (0, promptTools_1.promptProjectInfos)(serviceAccount);
    const app = await (0, serviceAccountTools_1.getFirebaseApp)(serviceAccount);
    const filename = await (0, promptTools_1.getFilenameWithOverwriteValidation)(options === null || options === void 0 ? void 0 : options.outputFile, options === null || options === void 0 ? void 0 : options.overwrite, 'remote_config', (options === null || options === void 0 ? void 0 : options.force) != true);
    if ((options === null || options === void 0 ? void 0 : options.force) != true) {
        await (0, promptTools_1.promptValidateOrExit)(`Are you sure you want to export the remote config from the project '${chalk.whiteBright(serviceAccount.project_id)}' to the file '${chalk.whiteBright(filename)}' ?`);
    }
    await (0, firebaseTools_1.exportJsonFromRemoteConfig)(filename, app);
    (0, promptTools_1.logSuccess)(`Successfully exported remote config from ${serviceAccount.project_id} into ${filename}.`);
}
//# sourceMappingURL=exportRemoteConfig.js.map