"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.importCollection = void 0;
const serviceAccountTools_1 = require("../utils/serviceAccountTools");
const fs = require("fs");
const chalk = require("chalk");
const promptTools_1 = require("../utils/promptTools");
const firebaseTools_1 = require("../utils/firebaseTools");
exports.importCollection = {
    name: 'import-collection',
    description: 'Import a collection from a local JSON',
    arguments: [
        {
            name: 'jsonPath',
            info: 'Path to the json file to import',
        },
    ],
    options: [
        {
            name: 'service-account-path',
            argName: 'serviceAccountPath',
            short: 's',
            info: 'Path to the service account used to access the project',
        },
        {
            name: 'batch',
            short: 'b',
            info: 'Use the batch API to push the collections faster (use for large collections)',
        },
        {
            name: 'force',
            short: 'f',
            info: 'Forces the operation to be executed without user validation',
        },
    ],
    action: importCollectionAction,
};
async function importCollectionAction(jsonPath, options) {
    const serviceAccount = (options === null || options === void 0 ? void 0 : options.serviceAccountPath)
        ? await (0, serviceAccountTools_1.validateAndParseServiceAccountPath)(options.serviceAccountPath, (options === null || options === void 0 ? void 0 : options.force) != true)
        : await (0, serviceAccountTools_1.getServiceAccountWithConfigOrUserInput)();
    (0, promptTools_1.promptProjectInfos)(serviceAccount);
    const app = await (0, serviceAccountTools_1.getFirebaseApp)(serviceAccount);
    const db = app.firestore();
    if (!fs.existsSync(jsonPath))
        (0, promptTools_1.exitProcess)(1, `File not found : ${jsonPath}`);
    if ((options === null || options === void 0 ? void 0 : options.force) != true) {
        await (0, promptTools_1.promptValidateOrExit)(`Are you sure you want to import the content of the file ${chalk.whiteBright(jsonPath)} to the project '${chalk.whiteBright(serviceAccount.project_id)}' ?`);
    }
    if (options === null || options === void 0 ? void 0 : options.batch) {
        await (0, firebaseTools_1.importJsonToFirestoreWithBatch)(jsonPath, db);
    }
    else {
        await (0, firebaseTools_1.importJsonToFirestore)(jsonPath, db);
    }
    (0, promptTools_1.logSuccess)(`Successfully imported data from ${jsonPath} to ${serviceAccount.project_id}.`);
}
//# sourceMappingURL=importCollection.js.map