"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.importRemoteConfig = void 0;
const serviceAccountTools_1 = require("../utils/serviceAccountTools");
const fs = require("fs");
const promptTools_1 = require("../utils/promptTools");
const chalk = require("chalk");
const firebaseTools_1 = require("../utils/firebaseTools");
exports.importRemoteConfig = {
    name: 'import-remote-config',
    description: 'Import remote config from a local JSON',
    arguments: [
        {
            name: 'jsonPath',
            info: 'Path to the json file to import in remote config',
        },
    ],
    options: [
        {
            name: 'service-account-path',
            argName: 'serviceAccountPath',
            short: 's',
            info: 'Path to the service account used to access the project',
        },
        {
            name: 'force',
            short: 'f',
            info: 'Forces the operation to be executed without user validation',
        },
    ],
    action: importRemoteConfigAction,
};
async function importRemoteConfigAction(jsonPath, options) {
    const serviceAccount = (options === null || options === void 0 ? void 0 : options.serviceAccountPath)
        ? await (0, serviceAccountTools_1.validateAndParseServiceAccountPath)(options.serviceAccountPath, (options === null || options === void 0 ? void 0 : options.force) != true)
        : await (0, serviceAccountTools_1.getServiceAccountWithConfigOrUserInput)();
    (0, promptTools_1.promptProjectInfos)(serviceAccount);
    const app = await (0, serviceAccountTools_1.getFirebaseApp)(serviceAccount);
    if (!fs.existsSync(jsonPath))
        (0, promptTools_1.exitProcess)(1, `File not found : ${jsonPath}`);
    if ((options === null || options === void 0 ? void 0 : options.force) != true) {
        await (0, promptTools_1.promptValidateOrExit)(`Are you sure you want to import the content of the file ${chalk.whiteBright(jsonPath)} to the remote config of the project '${chalk.whiteBright(serviceAccount.project_id)}' ?`);
    }
    await (0, firebaseTools_1.importJsonToRemoteConfig)(jsonPath, app);
    (0, promptTools_1.logSuccess)(`Successfully imported remote config from ${jsonPath} to ${serviceAccount.project_id}.`);
}
//# sourceMappingURL=importRemoteConfig.js.map