#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const importCollection_1 = require("./commands/importCollection");
const copyCollection_1 = require("./commands/copyCollection");
const deleteCollection_1 = require("./commands/deleteCollection");
const config_1 = require("./commands/config");
const blocklist_1 = require("./commands/blocklist");
const exportCollection_1 = require("./commands/exportCollection");
const importRemoteConfig_1 = require("./commands/importRemoteConfig");
const exportRemoteConfig_1 = require("./commands/exportRemoteConfig");
const commands = [
    importCollection_1.importCollection,
    exportCollection_1.exportCollection,
    copyCollection_1.copyCollection,
    deleteCollection_1.deleteCollections,
    importRemoteConfig_1.importRemoteConfig,
    exportRemoteConfig_1.exportRemoteConfig,
    config_1.config,
    blocklist_1.blocklist,
];
commander_1.program.name('firebase-cli');
commands.forEach((command) => {
    const commanderCommand = commander_1.program
        .command(command.name)
        .description(command.description)
        .action(command.action);
    command.arguments.forEach((argument) => {
        const name = argument.name + (argument.list ? '...' : '');
        const bracedName = argument.optional ? `[${name}]` : `\<${name}\>`;
        commanderCommand.argument(bracedName, argument.info);
    });
    command.options.forEach((option) => {
        const shortFlag = option.short ? `-${option.short}, ` : '';
        const longFlag = `--${option.name}${option.argName ? ` \<${option.argName + (option.list ? '...' : '')}\>` : ''}`;
        commanderCommand.option(`${shortFlag}${longFlag}`, option.info);
    });
});
commander_1.program.parse(process.argv);
//# sourceMappingURL=index.js.map