import { Config } from '../types/Config';
/**
 * Get the service account path saved in the config.json.
 * @return Either a service account path or undefined if none can be found in the local config.
 */
export declare function getServiceAccountPath(): string | undefined;
/**
 * Set the service account path in the config.json. You can pass it an existing config object if you already instantiated one.
 * @param { string } serviceAccountPath path to the service account.
 * @param { Config | undefined } config already instantiated config object.
 */
export declare function setDefaultServiceAccountPath(serviceAccountPath: string, config?: Config): void;
/**
 * Add projects to the blocklist in config.json.
 * @param { string[] } projectIds list of projects to add to the blocklist.
 * @param { Config | undefined } config already instantiated config object.
 */
export declare function addToBlocklist(projectIds: string[], config?: Config): void;
/**
 * Remove projects from the blocklist in config.json.
 * @param { string[] } projectIds list of projects to remove from the blocklist.
 * @param { Config | undefined } config already instantiated config object.
 */
export declare function removeFromBlocklist(projectIds: string[], config?: Config): void;
/**
 * Get the blocklist from config.json.
 * @return The list of blocklisted projects in the local config.
 */
export declare function getBlocklist(): string[];
