import { app, firestore } from 'firebase-admin';
import Firestore = firestore.Firestore;
import App = app.App;
/**
 * Ask user to choose one collection of the project.
 * @param { Firestore } db firestore instance.
 */
export declare function selectOneBetweenExistingCollections(db: Firestore): Promise<string>;
/**
 * Ask user to choose one or more collections of the project.
 * @param { Firestore } db firestore instance.
 */
export declare function selectManyBetweenExistingCollections(db: Firestore): Promise<string[]>;
/**
 * Check if the collections exist in the given project.
 * Returns true if all collections exist in the given project.
 * @param { Firestore } db firestore instance.
 * @param { string[] } collections list of collection names.
 */
export declare function collectionsExists(db: Firestore, collections: string[]): Promise<boolean>;
/**
 * Check the validity of given collections, ask the user to choose one or more if no collection given.
 * If allCollections is true and no collection is given, all the collections of the project will be selected.
 * @return A list of validated collections.
 * @param { Firestore } db firestore instance.
 * @param { boolean } allCollections select all collections of the project.
 * @param { string[] } collectionNames list of the names of the selected collections.
 * @param { string } projectId id of the current project id for logging.
 * @param { boolean } askUserIfInvalid true if you want to ask the user to select collections in case the given ones are not valid.
 */
export declare function validateCollectionList(db: Firestore, allCollections: boolean | undefined, collectionNames: string[] | undefined, projectId: string, askUserIfInvalid?: boolean): Promise<string[]>;
/** Firestore **/
/**
 * Import a JSON file to firestore using.
 * @param { string } jsonPath path to the json to import.
 * @param { Firestore } db firestore instance.
 */
export declare function importJsonToFirestore(jsonPath: string, db: Firestore): Promise<void>;
/**
 * Import a JSON file to firestore using the batch api.
 * @param { string } jsonPath path to the json to import.
 * @param { Firestore } db firestore instance.
 */
export declare function importJsonToFirestoreWithBatch(jsonPath: string, db: Firestore): Promise<firestore.WriteResult[]>;
/**
 * Export one or more collections as a JSON.
 * @param { string[] } collectionsName names of the collections to export.
 * @param { string } jsonPath path of the file to save.
 * @param { Firestore } db firestore instance.
 */
export declare function exportJsonFromFirestore(collectionsName: string[], jsonPath: string, db: Firestore): Promise<void>;
/**
 * Delete one or more collections from firestore.
 * @param { string } collectionsName name of the collections to delete.
 * @param { Firestore } db firestore instance.
 */
export declare function deleteCollectionsFromFirestore(collectionsName: string[], db: Firestore): Promise<firestore.WriteResult[]>;
/**
 * Copy one or more collections from a project to another.
 * @param { string[] } collectionsName name of the collections to copy.
 * @param { Firestore } sourceDb firestore instance of the source project.
 * @param { Firestore } destinationDb firestore instance of the destination project.
 */
export declare function copyCollectionAcrossProjects(collectionsName: string[], sourceDb: Firestore, destinationDb: Firestore): Promise<void>;
/** Remote Config **/
export declare function importJsonToRemoteConfig(jsonPath: string, app: App): Promise<string | boolean>;
export declare function exportJsonFromRemoteConfig(jsonPath: string, app: App): Promise<void>;
