import { ServiceAccount } from '../types/ServiceAccount';
/** Log **/
export declare function logError(message: string): void;
export declare function logSuccess(message: string): void;
export declare function exitProcess(code?: number, message?: string): never;
/** Prompt **/
/**
 *
 * @param serviceAccount
 */
export declare function promptProjectInfos(serviceAccount: ServiceAccount): void;
/**
 * Prompt a message and wait for user validation or cancellation. Expected inputs from user are yes or no.
 * Nothing is returned, the process either continues or is exited.
 * @param { string } message message to prompt.
 */
export declare function promptValidateOrExit(message: string): Promise<void>;
/**
 * Prompt a message and wait for user validation or cancellation.
 * Expected inputs from user are continueInput or cancelInput.
 * hintMessage is prompted when the user input does not match with the expected ones.
 * Nothing is returned, the process either continues or is exited.
 * @param { string } message message to prompt.
 * @param { string } continueInput expected input to continue process.
 * @param { string } cancelInput expected input to cancel process.
 * @param { string | undefined } hintMessage message prompted if the user does not type an expected input.
 */
export declare function promptCustomValidateOrExit(message: string, continueInput: string, cancelInput: string, hintMessage?: string): Promise<void>;
/**
 * Prompt a list within witch the user can select one element.
 * @return The element selected.
 * @param { string[] } choices list of the choices to select from.
 * @param { string } message message prompted to the user.
 */
export declare function promptListSelection(choices: string[], message: string): Promise<string>;
/**
 * Prompt a list within witch the user can select one or more elements.
 * @return All the selected elements.
 * @param { string[] } choices list of the choices to select from.
 * @param { string } message message prompted to the user.
 */
export declare function promptCheckbox(choices: string[], message: string): Promise<string[]>;
/**
 * Prompt a question to the user and wait for an input. The input can be validated with the validation function.
 * @return The user input.
 * @param { string } message message prompted to the user.
 * @param { (string) => (string | boolean) | undefined } validate function that validates user input.
 */
export declare function promptOpenQuestion(message: string, validate?: (input: string) => string | boolean): Promise<string>;
/**
 * Prompt a question to the user and wait for a binary response. The input can be validated with the validation function.
 * @return The result of the validate function applied on the user input.
 * @param { string } message message prompted to the user.
 * @param { (string) => (string | boolean) | undefined } validate function that validates user input.
 */
export declare function promptBinaryQuestion(message: string, validate?: (input: string) => string | boolean): Promise<boolean>;
/**
 * Generate a filename if the  `path` already exists and the user doesn't want to overwrite it.
 * @return { string } Generated filename.
 * @param { string | undefined } path path with filename to check.
 * @param { boolean | undefined } overwrite force to overwrite the file.
 * @param { string | undefined } defaultPrefix filename prefix.
 * @param { boolean } askUserIfOverwrite true if you want to ask the user if he wants to overwrite.
 */
export declare function getFilenameWithOverwriteValidation(path: string | undefined, overwrite: boolean | undefined, defaultPrefix?: string, askUserIfOverwrite?: boolean): Promise<string>;
export declare function executeOperationWithProgressBar(size: number, prefix: string | undefined, executeOperation: (increment: () => void) => Promise<void>): Promise<void>;
